# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector.api.fcm_credentials_api import FCMCredentialsApi  # noqa: E501


class TestFCMCredentialsApi(unittest.IsolatedAsyncioTestCase):
    """FCMCredentialsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = FCMCredentialsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_fcm_credentials_add_fcm_credentials(self) -> None:
        """Test case for fcm_credentials_add_fcm_credentials

        Add FCM credentials  # noqa: E501
        """
        pass

    async def test_fcm_credentials_get_fcm_credentials(self) -> None:
        """Test case for fcm_credentials_get_fcm_credentials

        Get FCM credentials  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
